GRAMMAR_DICT = {
    "entities": {
        "categories": {
            "fields": {
                "id": {
                    "description": "Dimensions ID of the category.",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
                "name": {
                    "description": "Name of the category. Note: this may include an identifier from the original source. E.g., '2.1 Biological and endogenous factors' (HRCS_RAC codes) or '1103 Clinical Sciences' (FOR codes).",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
            },
            "fieldsets": ["basics"],
        },
        "cities": {
            "fields": {
                "id": {
                    "description": "GeoNames city ID (eg '5391811' for `geonames:5391811 <http://www.geonames.org/5391811>`_ )",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
                "name": {
                    "description": "GeoNames city name.",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
            },
            "fieldsets": ["basics"],
        },
        "countries": {
            "fields": {
                "id": {
                    "description": "GeoNames country code (eg 'US' for `geonames:6252001 <http://www.geonames.org/6252001>`_ )",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
                "name": {
                    "description": "GeoNames country name.",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
            },
            "fieldsets": ["basics"],
        },
        "journals": {
            "fields": {
                "id": {
                    "description": "Dimensions ID of a journal. E.g., `jour.1016355 <https://app.dimensions.ai/discover/publication?and_facet_source_title=jour.1016355>`_ or `jour.1077219 <https://app.dimensions.ai/discover/publication?and_facet_source_title=jour.1077219>`_ .",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
                "title": {
                    "description": "Title of a journal publication. E.g. 'Nature' or 'The Lancet'",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
            },
            "fieldsets": ["basics"],
        },
        "open_access": {
            "fields": {
                "description": {
                    "description": "Description of the open access category.",
                    "is_filter": False,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
                "id": {
                    "description": "Dimensions ID of the open access category. E.g., one of 'closed', 'oa_all', 'gold_bronze', 'gold_pure', 'green_sub', 'gold_hybrid', 'green_pub', 'green_acc'. (see also the :ref:`publications` field ``open_access``).",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
                "name": {
                    "description": "Name of the open access category. E.g., 'Closed' or 'Pure Gold'.",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
            },
            "fieldsets": ["basics"],
        },
        "publication_links": {
            "fields": {
                "doi": {
                    "description": "Digital object identifier",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
                "id": {
                    "description": "Dimensions publication id",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
                "pmcid": {
                    "description": "PubMed Central ID",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
                "pmid": {
                    "description": "PubMed ID",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
            },
            "fieldsets": ["basics"],
        },
        "repositories": {
            "fields": {
                "id": {
                    "description": "Dimensions ID of the repository.",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
                "name": {
                    "description": "The name of the repository of the dataset.",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
            },
            "fieldsets": ["basics"],
        },
        "states": {
            "fields": {
                "id": {
                    "description": "GeoNames state code (ISO\u200c-3166-2). E.g., 'US.CA' for `geonames:5332921 <http://www.geonames.org/5332921>`_ .",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
                "name": {
                    "description": "GeoNames state name (ISO\u200c-3166-2).",
                    "is_filter": True,
                    "long_description": None,
                    "name": "string",
                    "type": "string",
                },
            },
            "fieldsets": ["basics"],
        },
    },
    "sources": {
        "clinical_trials": {
            "fields": {
                "abstract": {
                    "description": "Abstract or description of the clinical trial.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "acronym": {
                    "description": "Acronym of the clinical trial.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "active_years": {
                    "description": "List of active years for a clinical trial.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "integer",
                },
                "altmetric": {
                    "description": "Altmetric Attention Score.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "associated_grant_ids": {
                    "description": "Dimensions IDs of the grants associated to the clinical trial (see also: :ref:`clinical_trials_model` section).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "brief_title": {
                    "description": "Brief title of the clinical trial.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "category_bra": {
                    "description": "`Broad Research Areas <https://app.dimensions.ai/browse/publication/broad_research_areas?redirect_path=/discover/publication>`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_ (alias for most recent version).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2008": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2020": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hra": {
                    "description": "`Health Research Areas <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_hc": {
                    "description": "`HRCS - Health Categories <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_rac": {
                    "description": "`HRCS – Research Activity Codes <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_cso": {
                    "description": "`ICRP Common Scientific Outline <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_ct": {
                    "description": "`ICRP Cancer Types <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_rcdc": {
                    "description": "`Research, Condition, and Disease Categorization <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "conditions": {
                    "description": "List of medical conditions names, e.g. 'Breast cancer' or 'Obesity'.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "date_inserted": {
                    "description": "Date when the record was inserted into Dimensions (note: this field does not support exact match on the data, only range filters e.g. `<=` or `>=').",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "dimensions_url": {
                    "description": "Link pointing to the Dimensions web application",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "end_date": {
                    "description": "End of date of the clinical trial.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "funder_countries": {
                    "description": "The country group the funding organisations.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "countries",
                },
                "funders": {
                    "description": "GRID funding organisations that are involved with the clinical trial.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "gender": {
                    "description": "The gender of the clinical trial subjects e.g. 'Male', 'Female' or 'All'.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "id": {
                    "description": "Dimensions clinical trial ID",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "interventions": {
                    "description": "Structured JSON object containing information about the clinical trial's interventions according to the research plan or protocol created by the investigators.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": 'Returned objects contain: ``type``, ``name``, ``description``, ``arm_group_labels``.\n                                            \n                                            For example:\n                                            \n    .. code-block:: json\n                                     \n        {\n            "interventions":[\n                {\n                    "type":"Drug",\n                    "name":"INCB024360",\n                    "description":"INCB024360: Oral daily dosing",\n                    "arm_group_labels":"MEDI4736 + INCB024360",\n                },\n                {\n                    "type":"Drug",\n                    "name":"MEDI4736",\n                    "description":"MEDI4736 administered intravenously (IV) every two weeks (q2w)",\n                    "arm_group_labels":"MEDI4736 + INCB024360",\n                }\n            ]\n        }',
                    "type": "json",
                },
                "investigators": {
                    "description": "Additional details about investigators, including affiliations and roles.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "json",
                },
                "linkout": {
                    "description": "Original URL for the clinical trial.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "mesh_terms": {
                    "description": "Medical Subject Heading terms as used in PubMed.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "phase": {
                    "description": "Phase of the clinical trial, as a string.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "publication_ids": {
                    "description": "Publications mentioned in clinical trials (excluding resulting publications), as a list of Dimensions identifiers.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "publications": {
                    "description": "Publications mentioned in clinical trials (excluding resulting publications), as a structured entity.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "publication_links",
                },
                "registry": {
                    "description": "The platform where the clinical trial has been registered, e.g. 'ClinicalTrials.gov' or 'EU-CTR'.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "research_orgs": {
                    "description": "GRID organizations involved, e.g. as sponsors or collaborators.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "researchers": {
                    "description": "Dimensions researchers IDs associated to the clinical trial.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "researchers",
                },
                "score": {
                    "description": "For full-text queries, the relevance score is a numerical value assigned to a document that indicates how relevant that document is for a given query. Note: the score is query-specific i.e. it cannot be used to compare documents across queries.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "start_date": {
                    "description": "Start of date of the clinical trial.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "study_arms": {
                    "description": "The study arms.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "study_designs": {
                    "description": "The study design methods",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "study_eligibility_criteria": {
                    "description": "The eligibility criteria.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "study_maximum_age": {
                    "description": "The maximum age.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "study_minimum_age": {
                    "description": "The minimum age.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "study_outcome_measures": {
                    "description": "The study outcomes.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "json",
                },
                "study_participants": {
                    "description": "The number of participants.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "study_type": {
                    "description": "The type of study.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "title": {
                    "description": "The title of the clinical trial.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
            },
            "fieldsets": ["basics", "extras", "categories", "studies"],
            "metrics": {"count": {"description": "Total count", "name": "count"}},
            "search_fields": [
                "full_data",
                "investigators",
                "title_only",
                "title_abstract_only",
            ],
        },
        "datasets": {
            "fields": {
                "associated_grant_ids": {
                    "description": "The Dimensions IDs of the grants linked to the publication the dataset is associated with.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "associated_publication": {
                    "description": "Publication linked to the dataset (single value).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "publication_links",
                },
                "associated_publication_id": {
                    "description": "The Dimensions ID of the publication linked to the dataset (single value).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "authors": {
                    "description": "Ordered list of the dataset authors. ORCIDs are included if available.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": 'Returned objects contain: `name`, `orcid`\n                                            \n                                           For example:\n\n    .. code-block:: json\n    \n        {\n            "name": "Steffen Vogt",\n            "orcid": ""\n        }',
                    "type": "json",
                },
                "category_bra": {
                    "description": "`Broad Research Areas <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_ (alias for most recent version).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2008": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2020": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hra": {
                    "description": "`Health Research Areas <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_hc": {
                    "description": "`HRCS - Health Categories <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_rac": {
                    "description": "`HRCS – Research Activity Codes <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_cso": {
                    "description": "`ICRP Common Scientific Outline <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_ct": {
                    "description": "`ICRP Cancer Types <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_rcdc": {
                    "description": "`Research, Condition, and Disease Categorization <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_sdg": {
                    "description": "SDG - Sustainable Development Goals",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "date": {
                    "description": 'The publication date of the dataset, eg "2018-01-01".',
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "date_created": {
                    "description": "The creation date of the dataset.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "date_embargo": {
                    "description": "The embargo date of the dataset.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "date_inserted": {
                    "description": "Date when the record was inserted into Dimensions (note: this field does not support exact match on the data, only range filters e.g. `<=` or `>=').",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "date_modified": {
                    "description": "The last modification date of the dataset.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "description": {
                    "description": "Description of the dataset.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "dimensions_url": {
                    "description": "Link pointing to the Dimensions web application",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "doi": {
                    "description": "Dataset DOI.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "figshare_url": {
                    "description": "Figshare URL for the dataset.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "funder_countries": {
                    "description": "The country linked to the organisation funding the grant, expressed as GeoNames codes.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "countries",
                },
                "funders": {
                    "description": "The GRID organisations funding the dataset.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "id": {
                    "description": "Dimensions dataset ID.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "journal": {
                    "description": "The journal a data set belongs to.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "journals",
                },
                "keywords": {
                    "description": "Keywords used to describe the dataset (from authors).",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "language_desc": {
                    "description": "Dataset title language, as ISO 639-1 language codes.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "language_title": {
                    "description": "Dataset title language, as ISO 639-1 language codes.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "license_name": {
                    "description": "The dataset licence name, e.g. 'CC BY 4.0'.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "license_url": {
                    "description": "The dataset licence URL, e.g. 'https://creativecommons.org/licenses/by/4.0/'.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "repository": {
                    "description": "Repository associtated with the dataset.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "repositories",
                },
                "research_org_cities": {
                    "description": "City of the organisations the publication authors are affiliated to, expressed as GeoNames ID and name.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "cities",
                },
                "research_org_countries": {
                    "description": "Country of the organisations the publication authors are affiliated to, identified using GeoNames codes (note: this field supports count: count)..",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "countries",
                },
                "research_org_states": {
                    "description": "State of the organisations the publication authors are affiliated to, expressed as GeoNames codes (ISO\u200c-3166-2).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "states",
                },
                "research_orgs": {
                    "description": "GRID organisations linked to the publication associated to the dataset (note: this field supports count: count).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "researchers": {
                    "description": "Dimensions researchers IDs associated to the dataset's associated publication. Note: in most cases, these would be the same as the dataset authors.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "researchers",
                },
                "score": {
                    "description": "For full-text queries, the relevance score is a numerical value assigned to a document that indicates how relevant that document is for a given query. Note: the score is query-specific i.e. it cannot be used to compare documents across queries.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "title": {
                    "description": "Title of the dataset.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "year": {
                    "description": "Year of publication of the dataset.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
            },
            "fieldsets": ["basics", "categories"],
            "metrics": {"count": {"description": "Total count", "name": "count"}},
            "search_fields": ["full_data", "title_only", "title_abstract_only"],
        },
        "funder_groups": {
            "fields": {
                "id": {
                    "description": "The Dimensions ID of the group.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "name": {
                    "description": "The name of the group.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "organization_ids": {
                    "description": "The GRID IDs of the organizations which are members of this group.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
            },
            "fieldsets": ["basics"],
            "metrics": {"count": {"description": "Total count", "name": "count"}},
            "search_fields": ["name"],
        },
        "grants": {
            "fields": {
                "abstract": {
                    "description": "Abstract or summary from a grant proposal.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "active_year": {
                    "description": "List of active years for a grant.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "integer",
                },
                "category_bra": {
                    "description": "`Broad Research Areas <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for": {
                    "description": "ANZSRC Fields of Research classification (alias for most recent version).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2008": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2020": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hra": {
                    "description": "`Health Research Areas <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_hc": {
                    "description": "`HRCS - Health Categories <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_ .",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_rac": {
                    "description": "`HRCS – Research Activity Codes <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_ .",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_cso": {
                    "description": "`ICRP Common Scientific Outline <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_ct": {
                    "description": "`ICRP Cancer Types <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_rcdc": {
                    "description": "`Research, Condition, and Disease Categorization <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_ .",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_sdg": {
                    "description": "SDG - Sustainable Development Goals",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_uoa": {
                    "description": "`Units of Assessment <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "concepts": {
                    "description": "Concepts describing the main topics of a publication (note: automatically derived from the publication text using machine learning).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "json",
                },
                "concepts_scores": {
                    "description": "Relevancy scores for `concepts`.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": 'Returned objects contain: ``concept``, ``relevance``.\n                                            \n                                            For example:\n                                            \n    .. code-block:: json\n    \n        {\n            "concepts_scores": [\n                {\n                  "concept": "professional relations",\n                  "relevance": 0.08789352253426701\n                },\n                {\n                  "concept": "relation",\n                  "relevance": 0.062333122509877006\n                },\n                {\n                  "concept": "representation",\n                  "relevance": 0.025851134800039\n                },\n                {\n                  "concept": "skald",\n                  "relevance": 6.984149644517923e-05\n                },\n                {\n                  "concept": "Representations of Skalds",\n                  "relevance": 0.0\n                },\n                {\n                  "concept": "Sagas 1",\n                  "relevance": 0.0\n                }\n            ]\n        }',
                    "type": "json",
                },
                "date_inserted": {
                    "description": "Date when the record was inserted into Dimensions (note: this field does not support exact match on the data, only range filters e.g. `<=` or `>=`).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "dimensions_url": {
                    "description": "Link pointing to the Dimensions web application",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "end_date": {
                    "description": "Date when the grant ends.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "foa_number": {
                    "description": "The funding opportunity announcement (FOA) number, where available e.g. for grants from the US National Institute of Health (NIH) or from the National Science Foundation (NSF).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "funder_org_acronym": {
                    "description": None,
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "funder_org_cities": {
                    "description": "City name for funding organisation.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "cities",
                },
                "funder_org_countries": {
                    "description": "The country linked to the organisation funding the grant, expressed as GeoNames codes.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "countries",
                },
                "funder_org_name": {
                    "description": "Name of funding organisation.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "funder_org_states": {
                    "description": "State name for funding organisation.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "states",
                },
                "funder_orgs": {
                    "description": "The organisation funding the grant. This is normally a GRID organisation, but in very few cases a Dimensions funder ID is used.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "funding_aud": {
                    "description": "Funding amount awarded in AUD.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "funding_cad": {
                    "description": "Funding amount awarded in CAD.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "funding_chf": {
                    "description": "Funding amount awarded in CHF.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "funding_cny": {
                    "description": "Funding amount awarded in CNY.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "funding_currency": {
                    "description": "Original funding currency.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "funding_eur": {
                    "description": "Funding amount awarded in EUR.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "funding_gbp": {
                    "description": "Funding amount awarded in GBP.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "funding_jpy": {
                    "description": "Funding amount awarded in JPY.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "funding_nzd": {
                    "description": "Funding amount awarded in NZD.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "funding_schemes": {
                    "description": "Information that the data sources provide regarding grouping of grants according to funding schemes, programs, mechanisms etc. NOTE: funding scheme labels are not normalised and hence cannot be safely used for aggregrations.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "funding_usd": {
                    "description": "Funding amount awarded in USD.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "id": {
                    "description": "Dimensions grant ID.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "investigators": {
                    "description": "Additional details about investigators, including affiliations and roles e.g. 'PI' or 'Co-PI' (note: if the investigator has a Dimensions researcher ID, that is returned as well).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": 'Returned objects contain: ``id``, ``first_name``, ``middle_name``, ``last_name``, ``role``, ``affiliations``\n                                           \n                                           For example:\n\n    .. code-block:: json\n\n        {\n            "investigator_details":[\n                {\n                    "id":"ur.012516501745.79",\n                    "first_name":"O.",\n                    "middle_name":"",\n                    "last_name":"Mitas",\n                    "role":"PI",\n                    "affiliations":[\n                        {\n                            "id":"grid.5477.1",\n                            "name":"Breda University of Applied Sciences",\n                            "city":null,\n                            "city_id":"2745912",\n                            "state":null,\n                            "state_code":null,\n                            "country":null,\n                            "country_code":"NL"\n                        }\n                    ]\n                }\n            ]\n        }',
                    "type": "json",
                },
                "keywords": {
                    "description": "Keywords provided by the original data source.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "language": {
                    "description": "Grant original language, as ISO 639-1 language codes.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "language_title": {
                    "description": "ISO 639-1 language code for the original grant title.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "linkout": {
                    "description": "Original URL for the grant.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "original_title": {
                    "description": "Title of the grant in its original language.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "project_numbers": {
                    "description": "Grant identifiers, as provided by the source (e.g., funder, aggregator) the grant was derived from.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "json",
                },
                "research_org_cities": {
                    "description": "City of the research organisations receiving the grant, expressed as GeoNames id and name.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "cities",
                },
                "research_org_countries": {
                    "description": "Country of the research organisations receiving the grant, expressed as GeoNames code and name.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "countries",
                },
                "research_org_names": {
                    "description": "Names of organizations investigators are affiliated to. If the organization has a GRID ID, the canonical organization name is used. Otherwise the original affiliation string is used.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "research_org_state_codes": {
                    "description": "State of the organisations receiving the grant, expressed as GeoNames codes (ISO\u200c-3166-2).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "states",
                },
                "research_orgs": {
                    "description": "GRID organisations receiving the grant (note: identifiers are automatically extracted from the source text and can be missing in some cases).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "researchers": {
                    "description": "Dimensions researchers IDs associated to the grant.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "researchers",
                },
                "score": {
                    "description": "For full-text queries, the relevance score is a numerical value assigned to a document that indicates how relevant that document is for a given query. Note: the score is query-specific i.e. it cannot be used to compare documents across queries.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "start_date": {
                    "description": "Date when the grant starts, in the format 'YYYY-MM-DD'.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "start_year": {
                    "description": "Year when the grant starts.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "title": {
                    "description": "Title of the grant in English (if the grant language is not English, this field contains a translation of the title).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
            },
            "fieldsets": ["basics", "extras", "categories"],
            "metrics": {
                "count": {"description": "Total count", "name": "count"},
                "funding": {
                    "description": "Total funding amount, in USD.",
                    "name": "funding",
                },
            },
            "search_fields": [
                "full_data",
                "concepts",
                "investigators",
                "title_only",
                "title_abstract_only",
            ],
        },
        "organizations": {
            "fields": {
                "acronym": {
                    "description": 'GRID acronym of the organization. E.g., "UT" for `grid.26999.3d <https://app.dimensions.ai/details/organization/grid.26999.3d>`_',
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "city_name": {
                    "description": 'GRID name of the organization country. E.g., "Bethesda" for `grid.419635.c <https://app.dimensions.ai/details/organization/grid.419635.c>`_',
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "cnrs_ids": {
                    "description": "CNRS IDs for this organization",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "country_code": {
                    "description": "Country of the organisation, identified using GeoNames codes",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "country_name": {
                    "description": 'GRID name of the organization country. E.g., "Japan" for `grid.26999.3d <https://app.dimensions.ai/details/organization/grid.26999.3d>`_',
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "dimensions_url": {
                    "description": "Link pointing to the Dimensions web application",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "established": {
                    "description": "Year when the organization was estabilished",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "external_ids_fundref": {
                    "description": "Fundref IDs for this organization",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "hesa_ids": {
                    "description": "HESA IDs for this organization",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "id": {
                    "description": 'GRID ID of the organization. E.g., "grid.26999.3d".',
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "isni_ids": {
                    "description": "ISNI IDs for this organization",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "latitude": {
                    "description": None,
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "linkout": {
                    "description": None,
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "longitude": {
                    "description": None,
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "name": {
                    "description": 'GRID name of the organization. E.g., "University of Tokyo" for `grid.26999.3d <https://app.dimensions.ai/details/organization/grid.26999.3d>`_',
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "nuts_level1_code": {
                    "description": "Level 1 code for this organization, based on `Nomenclature of Territorial Units for Statistics <https://en.wikipedia.org/wiki/Nomenclature_of_Territorial_Units_for_Statistics>`_ (NUTS) codes of the European Union.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "nuts_level1_name": {
                    "description": "Level 1 name for this organization, based on `Nomenclature of Territorial Units for Statistics <https://en.wikipedia.org/wiki/Nomenclature_of_Territorial_Units_for_Statistics>`_ (NUTS) codes of the European Union.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "nuts_level2_code": {
                    "description": "Level 2 code for this organization, based on `Nomenclature of Territorial Units for Statistics <https://en.wikipedia.org/wiki/Nomenclature_of_Territorial_Units_for_Statistics>`_ (NUTS) codes of the European Union.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "nuts_level2_name": {
                    "description": "Level 2 name for this organization, based on `Nomenclature of Territorial Units for Statistics <https://en.wikipedia.org/wiki/Nomenclature_of_Territorial_Units_for_Statistics>`_ (NUTS) codes of the European Union.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "nuts_level3_code": {
                    "description": "Level 3 code for this organization, based on `Nomenclature of Territorial Units for Statistics <https://en.wikipedia.org/wiki/Nomenclature_of_Territorial_Units_for_Statistics>`_ (NUTS) codes of the European Union.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "nuts_level3_name": {
                    "description": "Level 3 name for this organization, based on `Nomenclature of Territorial Units for Statistics <https://en.wikipedia.org/wiki/Nomenclature_of_Territorial_Units_for_Statistics>`_ (NUTS) codes of the European Union.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "organization_child_ids": {
                    "description": "Child organization IDs",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "organization_parent_ids": {
                    "description": "Parent organization IDs",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "organization_related_ids": {
                    "description": "Related organization IDs",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "orgref_ids": {
                    "description": "OrgRef IDs for this organization",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "redirect": {
                    "description": "GRID ID of an organization this one was redirected to",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "ror_ids": {
                    "description": "ROR IDs for this organization",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "score": {
                    "description": "For full-text queries, the relevance score is a numerical value assigned to a document that indicates how relevant that document is for a given query. Note: the score is query-specific i.e. it cannot be used to compare documents across queries.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "state_name": {
                    "description": 'GRID name of the organization country. E.g., "Maryland" for `grid.419635.c <https://app.dimensions.ai/details/organization/grid.419635.c>`_',
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "status": {
                    "description": "Status of an organization. May be be one of:\n        \n        * `a`: active organization\n        * `o`: obsolete organization\n        * `r`: redirected organization, see field `redirect` to obtain the GRID ID of an organization this one was redirected to",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "types": {
                    "description": "Type of an organization. Available types include: ``Company``, ``Education``, ``Healthcare``, ``Nonprofit``, ``Facility``, ``Other``, ``Government``, ``Archive``.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "ucas_ids": {
                    "description": "UCAS IDs for this organization",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "ukprn_ids": {
                    "description": "UKPRN IDs for this organization",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "wikidata_ids": {
                    "description": "WikiData IDs for this organization",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "wikipedia_url": {
                    "description": "Wikipedia URL",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
            },
            "fieldsets": ["basics", "nuts"],
            "metrics": {"count": {"description": "Total count", "name": "count"}},
            "search_fields": ["full_data"],
        },
        "patents": {
            "fields": {
                "abstract": {
                    "description": "Abstract of the patent.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "additional_filters": {
                    "description": "Additional filters describing the patents, e.g. whether it's about a 'Research Organisation', or it is part of the 'Orange Book'.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "assignee_cities": {
                    "description": "City of the assignees of the patent, expressed as GeoNames ID and name (note: this value is extracted independently from GRID).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "cities",
                },
                "assignee_countries": {
                    "description": "Country of the assignees of the patent, expressed as GeoNames code and name (note: this value is extracted independently from GRID).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "countries",
                },
                "assignee_names": {
                    "description": "Name of assignees of the patent, as they appear in the original document.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "assignee_state_codes": {
                    "description": "State of the assignee, expressed using GeoNames (ISO\u200c-3166-2) codes (note: this value is extracted independently from GRID).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "states",
                },
                "assignees": {
                    "description": "Disambiguated GRID organisations who own or have owned the rights of a patent (note: this is a combination of `current_assignees` and `original_assignees` fields).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "associated_grant_ids": {
                    "description": "Dimensions IDs of the grants associated to the patent (see also: :ref:`patents_model` section).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "category_bra": {
                    "description": "`Broad Research Areas <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_ (alias for most recent version).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2008": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2020": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hra": {
                    "description": "`Health Research Areas <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_hc": {
                    "description": "`HRCS - Health Categories <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_rac": {
                    "description": "`HRCS – Research Activity Codes <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_cso": {
                    "description": "`ICRP Common Scientific Outline <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_ct": {
                    "description": "`ICRP Cancer Types <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_rcdc": {
                    "description": "`Research, Condition, and Disease Categorization <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "claims_amount": {
                    "description": "The number of claims associated with a patent.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "cpc": {
                    "description": "`Cooperative Patent Classification Categorization <https://www.epo.org/searching-for-patents/helpful-resources/first-time-here/classification/cpc.html>`_.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "current_assignee_names": {
                    "description": "Names of the organisations currently holding the patent, as they appear in the original document.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "current_assignees": {
                    "description": "Disambiguated GRID organisations currenlty owning the patent.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "date": {
                    "description": "Date when the patent was filed.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "date_inserted": {
                    "description": "Date when the record was inserted into Dimensions (note: this field does not support exact match on the data, only range filters e.g. `<=` or `>=`).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "dimensions_url": {
                    "description": "Link pointing to the Dimensions web application",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "expiration_date": {
                    "description": "Date when the patent expires.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "family_id": {
                    "description": "Identifier of the corresponding `EPO patent family <https://www.epo.org/searching-for-patents/helpful-resources/first-time-here/patent-families/docdb.html>`_.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "federal_support": {
                    "description": "The government interest statement describes how an invention was funded by a federal research grant or procurement contract.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "filing_status": {
                    "description": "Filing Status of the patent e.g. ‘Application’ or ‘Grant’ (note: this field is also called ‘Publication type’ in the Dimensions webapp).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "funder_countries": {
                    "description": "The country of the funding organisation (note: currently this information is available only for US patents).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "countries",
                },
                "funders": {
                    "description": "GRID organisations funding the patent.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "granted_date": {
                    "description": "The date on which the official body grants the patent.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "granted_year": {
                    "description": "The year on which the official body grants the patent.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "id": {
                    "description": "Dimensions patent ID",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "inventor_names": {
                    "description": "Names of the people who invented the patent.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "inventors": {
                    "description": "Details of the people who invented the patent.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "json",
                },
                "ipcr": {
                    "description": "`International Patent Classification Reform Categorization <https://www.wipo.int/classifications/ipc/en/faq/>`_.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "jurisdiction": {
                    "description": "The jurisdiction where the patent was granted, e.g. 'US', 'DE', 'EP'...",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "legal_status": {
                    "description": "The legal status of the patent, e.g. 'Granted', 'Active', 'Abandoned' etc..",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "orange_book": {
                    "description": "Data added from the FDA Orange Book Data Files.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "json",
                },
                "original_assignee_names": {
                    "description": "Name of the organisations that first owned the patent, as they appear in the original document.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "original_assignees": {
                    "description": "Disambiguated GRID organisations that first owned the patent.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "priority_date": {
                    "description": "The earliest filing date in a family of patent applications.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "priority_year": {
                    "description": "The filing year of the earliest application of which priority is claimed.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "publication_date": {
                    "description": "Date of publication of a patent.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "publication_ids": {
                    "description": "Dimensions IDs of the publications related to this patent (see also: :ref:`patents_model` section).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "publication_year": {
                    "description": "Year of publication of a patent.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "publications": {
                    "description": "Publication IDs of the publications related to this patent (see also: :ref:`patents_model` section).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "publication_links",
                },
                "reference_ids": {
                    "description": "Dimensions IDs of the patents which are cited by this patent (see also: :ref:`patents_model` section).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "researchers": {
                    "description": "Researcher IDs matched to the patent's inventors list. (note: this returns only the disambiguated inventors of a patent; in order to get the full list of inventors, the field `inventors` should be used).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "researchers",
                },
                "score": {
                    "description": "For full-text queries, the relevance score is a numerical value assigned to a document that indicates how relevant that document is for a given query. Note: the score is query-specific i.e. it cannot be used to compare documents across queries.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "times_cited": {
                    "description": "The number of times the patent has been cited by other patents.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "title": {
                    "description": "The title of the patent.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "year": {
                    "description": "The year the patent was filed.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
            },
            "fieldsets": ["basics", "extras", "categories"],
            "metrics": {"count": {"description": "Total count", "name": "count"}},
            "search_fields": [
                "full_data",
                "inventors",
                "title_only",
                "title_abstract_only",
            ],
        },
        "policy_documents": {
            "fields": {
                "category_bra": {
                    "description": "`Broad Research Areas <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_ (alias for most recent version).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2008": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2020": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hra": {
                    "description": "`Health Research Areas <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_hc": {
                    "description": "`HRCS - Health Categories <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_rac": {
                    "description": "`HRCS – Research Activity Codes <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_cso": {
                    "description": "`ICRP Common Scientific Outline <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_ct": {
                    "description": "`ICRP Cancer Types <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_rcdc": {
                    "description": "`Research, Condition, and Disease Categorization <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "date_inserted": {
                    "description": "Date when the record was inserted into Dimensions (note: this field does not support exact match on the data, only range filters e.g. `<=` or `>=`).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "dimensions_url": {
                    "description": "Link pointing to the Dimensions web application",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "id": {
                    "description": "Dimensions policy document ID",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "linkout": {
                    "description": "Original URL for the policy document.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "publication_ids": {
                    "description": "Dimensions IDs of the publications related to this policy document (see also: :ref:`policy_documents_model` section).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "publications": {
                    "description": "Publication IDs of the publications related to this policy document (see also: :ref:`policy_documents_model` section).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "publication_links",
                },
                "publisher_org": {
                    "description": "GRID organization publishing the policy document.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "organizations",
                },
                "publisher_org_city": {
                    "description": "City of the organization publishing the policy document.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "cities",
                },
                "publisher_org_country": {
                    "description": "Country of the organization publishing the policy document.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "countries",
                },
                "publisher_org_state": {
                    "description": "State of the organization publishing the policy document.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "states",
                },
                "score": {
                    "description": "For full-text queries, the relevance score is a numerical value assigned to a document that indicates how relevant that document is for a given query. Note: the score is query-specific i.e. it cannot be used to compare documents across queries.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "title": {
                    "description": "Title of the policy document.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "year": {
                    "description": "Year of publication of the policy document.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
            },
            "fieldsets": ["basics", "categories"],
            "metrics": {"count": {"description": "Total count", "name": "count"}},
            "search_fields": ["full_data", "title_only"],
        },
        "publications": {
            "fields": {
                "abstract": {
                    "description": "The publication abstract.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "acknowledgements": {
                    "description": "The acknowledgements section text as found in the source document.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "altmetric": {
                    "description": "Altmetric Attention Score.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "altmetric_id": {
                    "description": "Altmetric Publication ID",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "arxiv_id": {
                    "description": "The publications arXiv identifier (e.g. ‘arXiv:2102.02477’).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "authors": {
                    "description": "Ordered list of authors names and their affiliations, as they appear in the original publication. The list can include researcher and organization identifiers, when available (note: in order to search for disambiguated authors, use the `in researchers` syntax).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": 'Returned objects contain: ``first_name``, ``last_name``, ``corresponding``, ``orcid``, ``current_organization_id``, ``researcher_id``, ``affiliations`` and ``raw_affiliation``.\n\n        For example:\n        \n        .. code-block:: json\n        \n                {\n                    "raw_affiliation": [\n                        "Centre for Operational Research, International Union Against Tuberculosis and Lung Disease (The Union), Paris, France.",\n                        "Centre for Operational Research, The Union South-East Asia Office, New Delhi, India."\n                    ],\n                    "first_name": "Pruthu",\n                    "last_name": "Thekkur",\n                    "corresponding": "",\n                    "orcid": "[\'s\']",\n                    "researcher_id": "ur.0670077515.38",\n                    "affiliations": [\n                        {\n                            "raw_affiliation": "Centre for Operational Research, International Union Against Tuberculosis and Lung Disease (The Union), Paris, France.",\n                            "id": "grid.435357.3",\n                            "name": "International Union Against Tuberculosis and Lung Disease",\n                            "city": "Paris",\n                            "city_id": 2988507,\n                            "country": "France",\n                            "country_code": "FR",\n                            "state": null,\n                            "state_code": null\n                        },\n                        {\n                            "raw_affiliation": "Centre for Operational Research, The Union South-East Asia Office, New Delhi, India.",\n                            "id": "grid.8195.5",\n                            "name": "University of Delhi",\n                            "city": "New Delhi",\n                            "city_id": 1261481,\n                            "country": "India",\n                            "country_code": "IN",\n                            "state": null,\n                            "state_code": null\n                        }\n                    ]\n                }',
                    "type": "json",
                },
                "authors_count": {
                    "description": "Count of authors, as they appear in the original publication.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "book_doi": {
                    "description": "The DOI of the book a chapter belongs to (note: this field is available only for chapters).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "book_series_title": {
                    "description": "The title of the book series book, belong to.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "book_title": {
                    "description": "The title of the book a chapter belongs to (note: this field is available only for chapters).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "category_bra": {
                    "description": "`Broad Research Areas <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_ (alias for most recent version).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2008": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2020": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hra": {
                    "description": "`Health Research Areas <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_hc": {
                    "description": "`HRCS - Health Categories <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_rac": {
                    "description": "`HRCS – Research Activity Codes <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_cso": {
                    "description": "`ICRP Common Scientific Outline <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_ct": {
                    "description": "`ICRP Cancer Types <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_rcdc": {
                    "description": "`Research, Condition, and Disease Categorization <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_sdg": {
                    "description": "SDG - Sustainable Development Goals",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_uoa": {
                    "description": "`Units of Assessment <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "clinical_trial_ids": {
                    "description": "Clinical Trial IDs mentioned in publications full text.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "concepts": {
                    "description": "Concepts describing the main topics of a publication (note: automatically derived from the publication text using machine learning).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "json",
                },
                "concepts_scores": {
                    "description": "Relevancy scores for `concepts`.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": 'Returned objects contain: ``concept``, ``relevance``.\n                                            \n                                            For example:\n                                            \n    .. code-block:: json\n    \n        {\n            "concepts_scores": [\n                {\n                  "concept": "professional relations",\n                  "relevance": 0.088\n                },\n                {\n                  "concept": "relation",\n                  "relevance": 0.062\n                },\n                {\n                  "concept": "representation",\n                  "relevance": 0.025\n                },\n                {\n                  "concept": "skald",\n                  "relevance": 6.984\n                },\n                {\n                  "concept": "Representations of Skalds",\n                  "relevance": 0.0\n                },\n                {\n                  "concept": "Sagas 1",\n                  "relevance": 0.0\n                }\n            ]\n        }',
                    "type": "json",
                },
                "date": {
                    "description": 'The publication date for the version of record of a document (note: incomplete dates are always normalised as ‘YYYY-MM-DD’, so "2018-01" becomes "2018-01-01".).',
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "date_inserted": {
                    "description": "Date when the record was inserted into Dimensions (note: this field does not support exact match on the data, only range filters e.g. `<=` or `>=').",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "date_online": {
                    "description": "The publication online date.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "date_print": {
                    "description": "The publication print date.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "dimensions_url": {
                    "description": "Link pointing to the Dimensions web application",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "doi": {
                    "description": "Digital object identifier.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "editors": {
                    "description": "For supported publication types, the associated editors.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "field_citation_ratio": {
                    "description": "Relative citation performance of article when compared to similarly aged articles in its area of research (note: does not support emptiness filters).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "funder_countries": {
                    "description": "The country of the organisations funding this publication.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "countries",
                },
                "funders": {
                    "description": "The GRID organisation funding this publication.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "funding_section": {
                    "description": "The funding section text as found in the source document",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "id": {
                    "description": "Dimensions publication ID.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "isbn": {
                    "description": "International Standard Book Number (ISBN).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "issn": {
                    "description": "International Standard Serial Number",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "issue": {
                    "description": "The issue number of a publication.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "journal": {
                    "description": "The journal a publication belongs to.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "journals",
                },
                "journal_lists": {
                    "description": "Independent grouping of journals outside of Dimensions, e.g. 'ERA 2015' or 'Norwegian register level 1'.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "journal_title_raw": {
                    "description": "The journal title, as it appears in the original source (note: this field can be used to retrieve historical titles of journals whose official title was later updated).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "linkout": {
                    "description": "Original URL for a publication full text.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "mesh_terms": {
                    "description": "Medical Subject Heading terms as used in PubMed.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "open_access": {
                    "description": "Open Access categories for publications `(latest version) <https://www.dimensions.ai/wp-content/uploads/2021/02/Dimensions_New-OA-status-definition.pdf>`_",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": "Open Access category data for publications values:\n\n        * `oa_all`: Publication is either gold, hybrid, bronze or green OA.\n        * `hybrid`: Publication freely available under an open licence in a paid-access journal\n        * `bronze`: Document freely available on publisher page, but without an open licence and not in a full OA journal\n        * `gold`: Publication published in a full OA journal\n        * `green`: Free copy of the publication available in an OA repository\n        * `closed`: No freely available copy has been identified",
                    "type": "string",
                },
                "pages": {
                    "description": "The pages of the publication, as they would appear in a citation record.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "pmcid": {
                    "description": "PubMed Central ID.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "pmid": {
                    "description": "PubMed ID.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "proceedings_title": {
                    "description": "Title of the conference proceedings volume associated to a publication.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "publisher": {
                    "description": "Name of the publisher as a string.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "recent_citations": {
                    "description": "Number of citations received in the last two years. Does not support emptiness filters",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "reference_ids": {
                    "description": "Dimensions publication ID for publications in the references list, i.e. outgoing citations (see also: :ref:`publications_model` section).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "referenced_pubs": {
                    "description": "Publication IDs of the publications in the references list, i.e. outgoing citations.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "publication_links",
                },
                "relative_citation_ratio": {
                    "description": "Relative citation performance of an article when compared to others in its area of research (note: does not support emptiness filters).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "research_org_cities": {
                    "description": "City of the organisations authors are affiliated to, expressed as GeoNames ID and name.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "cities",
                },
                "research_org_countries": {
                    "description": "Country of the organisations authors are affiliated to, identified using GeoNames codes (note: this field supports :ref:`filter-functions`: ``count``).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "countries",
                },
                "research_org_country_names": {
                    "description": "Country name of the organisations authors are affiliated to, as a string.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "research_org_names": {
                    "description": "Names of organizations authors are affiliated to. If the organization has a GRID ID, the canonical organization name is used. Otherwise the original affiliation string is used.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "research_org_state_codes": {
                    "description": "State of the organisations authors are affiliated to, expressed as GeoNames codes (ISO\u200c-3166-2).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "states",
                },
                "research_org_state_names": {
                    "description": "State name of the organisations authors are affiliated to, as a string.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "research_orgs": {
                    "description": "GRID organisations associated to a publication. Identifiers are automatically extracted from author affiliations text, so they can be missing in some cases (note: this field supports :ref:`filter-functions`: ``count``).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "researchers": {
                    "description": "Researcher IDs matched to the publication's authors list. (note: this returns only the disambiguated authors of a publication; in order to get the full authors list, the field `authors` should be used). This field supports :ref:`filter-functions`: ``count``.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "researchers",
                },
                "resulting_publication_doi": {
                    "description": "For preprints, the DOIs of the resulting full publications.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "score": {
                    "description": "For full-text queries, the relevance score is a numerical value assigned to a document that indicates how relevant that document is for a given query. Note: the score is query-specific i.e. it cannot be used to compare documents across queries.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "source_title": {
                    "description": "Source Title for the Publication.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "source_titles",
                },
                "subtitles": {
                    "description": "Subtitles of a publication (when available).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "supporting_grant_ids": {
                    "description": "Grants supporting a publication, returned as a list of dimensions grants IDs  (see also: :ref:`publications_model` section).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "times_cited": {
                    "description": "Number of citations (note: does not support emptiness filters).",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "title": {
                    "description": "Title of a publication.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "type": {
                    "description": "Publication type (one of: article, chapter, proceeding, monograph, preprint or book).",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "volume": {
                    "description": "Publication volume.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "year": {
                    "description": "The year for the version of record of publication (note: when the `date` field is available, this is equal to the year part of the full date).",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
            },
            "fieldsets": ["basics", "extras", "book", "categories"],
            "metrics": {
                "altmetric_avg": {
                    "description": "Altmetric Attention Score mean",
                    "name": "altmetric_avg",
                },
                "altmetric_median": {
                    "description": "Median Altmetric Attention Score",
                    "name": "altmetric_median",
                },
                "citations_avg": {
                    "description": "Arithmetic mean of citations",
                    "name": "citations_avg",
                },
                "citations_median": {
                    "description": "Median of citations",
                    "name": "citations_median",
                },
                "citations_total": {
                    "description": "Aggregated number of citations",
                    "name": "citations_total",
                },
                "count": {"description": "Total count", "name": "count"},
                "fcr_gavg": {
                    "description": "Geometric mean of `field_citation_ratio` field (note: This field cannot be used for sorting results).",
                    "name": "fcr_gavg",
                },
                "rcr_avg": {
                    "description": "Arithmetic mean of `relative_citation_ratio` field.",
                    "name": "rcr_avg",
                },
                "recent_citations_total": {
                    "description": "For a given article, in a given year, the number of citations accrued in the last two year period. Single value stored per document, year window rolls over in July.",
                    "name": "recent_citations_total",
                },
            },
            "search_fields": [
                "terms",
                "full_data_exact",
                "concepts",
                "raw_affiliations",
                "acknowledgements",
                "title_only",
                "title_abstract_only",
                "full_data",
                "authors",
            ],
        },
        "reports": {
            "fields": {
                "abstract": {
                    "description": "The abstract of the report.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "authors": {
                    "description": "Ordered list of authors names and their affiliations, as they appear in the source. The list can include researcher and organization identifiers, when available.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "json",
                },
                "category_bra": {
                    "description": "`Broad Research Areas <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_ (alias for most recent version).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2008": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_for_2020": {
                    "description": "`ANZSRC Fields of Research classification <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hra": {
                    "description": "`Health Research Areas <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_hc": {
                    "description": "`HRCS - Health Categories <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_hrcs_rac": {
                    "description": "`HRCS – Research Activity Codes <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_cso": {
                    "description": "`ICRP Common Scientific Outline <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_icrp_ct": {
                    "description": "`ICRP Cancer Types <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_rcdc": {
                    "description": "`Research, Condition, and Disease Categorization <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_sdg": {
                    "description": "SDG - Sustainable Development Goals",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "category_uoa": {
                    "description": "`Units of Assessment <https://dimensions.freshdesk.com/support/solutions/articles/23000018820-what-are-fields-of-research-and-other-classification-systems-and-how-are-they-created->`_",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "categories",
                },
                "concepts": {
                    "description": "Concepts describing the main topics of the report (note: automatically derived from the text using machine learning).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "json",
                },
                "concepts_scores": {
                    "description": "Relevancy scores for `concepts`.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": 'Returned objects contain: ``concept``, ``relevance``.\n                                            \n                                            For example:\n                                            \n    .. code-block:: json\n    \n        {\n            "concepts_scores": [\n                {\n                  "concept": "professional relations",\n                  "relevance": 0.088\n                },\n                {\n                  "concept": "relation",\n                  "relevance": 0.062\n                },\n                {\n                  "concept": "representation",\n                  "relevance": 0.025\n                },\n                {\n                  "concept": "skald",\n                  "relevance": 6.984\n                },\n                {\n                  "concept": "Representations of Skalds",\n                  "relevance": 0.0\n                },\n                {\n                  "concept": "Sagas 1",\n                  "relevance": 0.0\n                }\n            ]\n        }',
                    "type": "json",
                },
                "date": {
                    "description": "Date when the report was published, in the format 'YYYY-MM-DD'.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "date_inserted": {
                    "description": "Date when the record was inserted into Dimensions (note: this field does not support exact match on the data, only range filters e.g. `<=` or `>=').",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "date",
                },
                "doi": {
                    "description": "Digital object identifier.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "external_ids": {
                    "description": "External identifiers available from the report publisher (e.g. OSTI ID).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "json",
                },
                "funder_details": {
                    "description": "Sponsors/funders of the research/report, as they appear in the source.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "json",
                },
                "funder_orgs": {
                    "description": "GRID organizations funding the report (only disambiguated).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "funder_orgs_countries": {
                    "description": "Countries of the organizations funding the report.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "countries",
                },
                "id": {
                    "description": "Dimensions report ID.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "keywords": {
                    "description": "Keywords, as provided by the source.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "linkout": {
                    "description": "Original URL for the report.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "publisher_details": {
                    "description": "Organizations publishing the report, as they appear in the source.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "json",
                },
                "publisher_orgs": {
                    "description": "GRID organizations publishing the report (only disambiguated).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "publisher_orgs_countries": {
                    "description": "Countries of the organizations publishing the report.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "countries",
                },
                "research_org_cities": {
                    "description": "Cities of the organisations associated with the report, expressed as GeoNames ID and name.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "cities",
                },
                "research_org_countries": {
                    "description": "Countries of the organisations associated with the report, expressed as GeoNames code and name.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "countries",
                },
                "research_org_states": {
                    "description": "States of the organisations associated with the report, expressed as GeoNames codes (ISO-3166-2).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "states",
                },
                "research_orgs": {
                    "description": "Combined list of GRID organisations associated with the report, because the source marks them as responsible for it, or because they appear as authors affiliations.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "responsible_orgs": {
                    "description": "GRID organizations responsible for the report. Note: this can be different from the author affiliations.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "responsible_orgs_cities": {
                    "description": "Cities of the organisations responsible for the report, expressed as GeoNames ID and name.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "cities",
                },
                "responsible_orgs_countries": {
                    "description": "Countries of the organisations responsible for the report, expressed as GeoNames code and name.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "countries",
                },
                "responsible_orgs_details": {
                    "description": "Organizations responsible for the report, as they appear in the source. Note: this can be different from the author affiliations.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "json",
                },
                "responsible_orgs_states": {
                    "description": "States of the organisations responsible for the report, expressed as GeoNames codes (ISO-3166-2).",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "states",
                },
                "score": {
                    "description": "For full-text queries, the relevance score is a numerical value assigned to a document that indicates how relevant that document is for a given query. Note: the score is query-specific i.e. it cannot be used to compare documents across queries.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "title": {
                    "description": "Title of a report.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "year": {
                    "description": "Year when the report was published (note: when the `date` field is available, this is equal to the year part of the full date).",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
            },
            "fieldsets": ["basics", "categories"],
            "metrics": {"count": {"description": "Total count", "name": "count"}},
            "search_fields": ["full_data", "title_abstract_only"],
        },
        "researchers": {
            "fields": {
                "current_research_org": {
                    "description": "The most recent research organization linked to the researcher.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "organizations",
                },
                "dimensions_url": {
                    "description": "Link pointing to the Dimensions web application",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "first_grant_year": {
                    "description": "First year the researcher was awarded a grant.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "first_name": {
                    "description": "First Name.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "first_publication_year": {
                    "description": None,
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "id": {
                    "description": "Dimensions researcher ID.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "last_grant_year": {
                    "description": "Last year the researcher was awarded a grant.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "last_name": {
                    "description": "Last Name.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "last_publication_year": {
                    "description": None,
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "nih_ppid": {
                    "description": "The PI Profile ID (i.e., ppid) is a Researcher ID from the US National Institute of Health (NIH).",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "obsolete": {
                    "description": "Indicates researcher ID status. 0 means that the researcher ID is still active, 1 means that the researcher ID is no longer valid. See the `redirect` field for further information on invalid researcher IDs.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "orcid_id": {
                    "description": "`ORCID <https://orcid.org/>`_ ID.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "redirect": {
                    "description": "Indicates status of a researcher ID marked as obsolete. Empty means that the researcher ID was deleted. Otherwise ID provided means that is the new ID into which the obsolete one was redirected. If multiple values are available, it means that the original researcher ID was split into multiple IDs.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "research_orgs": {
                    "description": "All research organizations linked to the researcher.",
                    "is_entity": True,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "organizations",
                },
                "score": {
                    "description": "For full-text queries, the relevance score is a numerical value assigned to a document that indicates how relevant that document is for a given query. Note: the score is query-specific i.e. it cannot be used to compare documents across queries.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "total_grants": {
                    "description": "Total grants count.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "total_publications": {
                    "description": "Total publications count.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
            },
            "fieldsets": ["basics", "extras"],
            "metrics": {"count": {"description": "Total count", "name": "count"}},
            "search_fields": [],
        },
        "source_titles": {
            "fields": {
                "id": {
                    "description": "The Dimensions ID of the source.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "issn": {
                    "description": "List of known ISSNs for the source, including both print and electronic.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
                "issn_electronic": {
                    "description": "Electronic ISSN for the source.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "issn_print": {
                    "description": "Print ISSN for the source.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "linkout": {
                    "description": "The source web URL, if known.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "publisher": {
                    "description": "The name of the source publisher entity.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "score": {
                    "description": "For full-text queries, the relevance score is a numerical value assigned to a document that indicates how relevant that document is for a given query. Note: the score is query-specific i.e. it cannot be used to compare documents across queries.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "sjr": {
                    "description": "SJR indicator (SCImago Journal Rank). This indicator measures both the number of citations received by a journal and the importance or prestige of the journals where the citations come from.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "snip": {
                    "description": "SNIP indicator (source normalized impact per paper). This indicator measures the average citation impact of the publications of a journal.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "float",
                },
                "start_year": {
                    "description": "Year when the source started publishing.",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "integer",
                },
                "title": {
                    "description": "The title of the source.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": False,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "type": {
                    "description": "The source type: one of `book_series`, `proceeding`, `journal`, `preprint_platform` (4 in total).",
                    "is_entity": False,
                    "is_facet": True,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
            },
            "fieldsets": ["basics"],
            "metrics": {"count": {"description": "Total count", "name": "count"}},
            "search_fields": ["title_only"],
        },
        "research_org_groups": {
            "fields": {
                "id": {
                    "description": "The Dimensions ID of the group.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "name": {
                    "description": "The name of the group.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": False,
                    "long_description": None,
                    "type": "string",
                },
                "organization_ids": {
                    "description": "The GRID IDs of the organizations which are members of this group.",
                    "is_entity": False,
                    "is_facet": False,
                    "is_filter": True,
                    "is_multivalue": True,
                    "long_description": None,
                    "type": "string",
                },
            },
            "fieldsets": ["basics"],
            "metrics": {"count": {"description": "Total count", "name": "count"}},
            "search_fields": ["name"],
        },
    },
}
